@@ -27,10 +27,12 @@
 #' structural equation models. Psychological Methods, 21, 151-163.
 #' \doi{10.1037/met0000038}
 #' @examples
+#' if(requireNamespace("OpenMx", quietly = TRUE)){
 #' df <- iris[c(1:5, 100:105), 1:3]
 #' names(df) <- letters[1:3]
 #' res <- mx_profiles(df, classes = 1:2)
 #' lr_lmr(res)
+#' }
 #' @rdname lr_lmr
 #' @export
 lr_lmr <- function(x, ...){
@@ -59,7 +61,7 @@ lr_lmr.MxModel <- function(x, ...){
             score1 = function(x)mixgrads(x) * -.5,
             score2 = function(x)mixgrads(x) * -.5,
             nested = FALSE)
-  out <- data.frame(lr = -1*lr_res$LRTstat, df = length(omxGetParameters(object2)) - length(omxGetParameters(object1)), p = max(c(.Machine$double.eps, lr_res$p_LRT$B)), w2 = lr_res$omega, p_w2 = max(c(.Machine$double.eps, lr_res$p_omega)))
+  out <- data.frame(lr = -1*lr_res$LRTstat, df = length(OpenMx::omxGetParameters(object2)) - length(OpenMx::omxGetParameters(object1)), p = max(c(.Machine$double.eps, lr_res$p_LRT$B)), w2 = lr_res$omega, p_w2 = max(c(.Machine$double.eps, lr_res$p_omega)))
   class(out) <- c("LRT", class(out))
   attr(out, "type") <- "Lo-Mendell-Rubin adjusted"
   return(out)
@@ -94,19 +96,19 @@ lr_lmr.mixture_list <- function(x, ...){
 
 mixgrads <- function(model){
   if(!isTRUE("mixture" %in% attr(model, "tidySEM")) & length(names(model@submodels)) > 1){
-    return(imxRowGradients(model))
+    return(OpenMx::imxRowGradients(model))
   }
-  paramLabels <- names(omxGetParameters(model))
+  paramLabels <- names(OpenMx::omxGetParameters(model))
   numParam <- length(paramLabels)
   custom.compute <-
-    mxComputeSequence(list(
-      mxComputeNumericDeriv(checkGradient = FALSE,
+    OpenMx::mxComputeSequence(list(
+      OpenMx::mxComputeNumericDeriv(checkGradient = FALSE,
                             hessian = FALSE),
-      mxComputeReportDeriv()
+      OpenMx::mxComputeReportDeriv()
     ))
   grads <- do.call(rbind, lapply(1:nrow(model@data$observed), function(i) {
     tryCatch({
-      mxRun(mxModel(model, custom.compute, mxData(model@data$observed[i, , drop = FALSE], "raw")), silent = TRUE)$output$gradient
+      OpenMx::mxRun(OpenMx::mxModel(model, custom.compute, OpenMx::mxData(model@data$observed[i, , drop = FALSE], "raw")), silent = TRUE)$output$gradient
     },
     error = function(e) {
       rep(NA, length(numParam))
