@@ -88,10 +88,12 @@ get_cordat.MxModel <- function(x){
 #' @author Caspar J. van Lissa
 #' @export
 #' @examples
+#' if(requireNamespace("OpenMx", quietly = TRUE)){
 #' iris_sample <- iris[c(1:5, 145:150), c("Sepal.Length", "Sepal.Width")]
 #' names(iris_sample) <- c("x", "y")
 #' res <- mx_profiles(iris_sample, classes = 2)
 #' plot_bivariate(res, rawdata = FALSE)
+#' }
 #' @keywords mixture correlation plot
 #' @rdname plot_bivariate
 #' @export
@@ -297,10 +299,6 @@ merge_corplots <- function(plots, ...) {
         plot2_grobs$grobs[[which(sapply(plot2_grobs$grobs, `[[`, "name") == "guide-box")]]
       width_grob <- grobWidth(plot2_grobs$grobs[[grep("^axis.title.y.left", sapply(plot2_grobs$grobs, `[[`, "name"))]])
 
-      # axes <- lapply(plots[1:n_vars], function(x){
-      #     tmp <- ggplot_gtable(ggplot_build(x))
-      #     tmp$grobs[[grep("^axis.title.y.left", sapply(tmp$grobs, `[[`, "name"))]]
-      #     })
 
       model_mat <- matrix(1L:(n_vars * n_vars), nrow = n_vars)
       model_mat[upper.tri(model_mat)] <- NA
@@ -362,17 +360,12 @@ merge_corplots <- function(plots, ...) {
           plots[[x]]$widths[4] <- plots[[x]]$widths[4]+width_grob
         }
         plots[[x]]$heights <- fixed_heights
-        if(!x %in% model_mat[nrow(model_mat), ]){
-          plots[[x]]$heights[c(1,9)] <- unit(0, "cm")
-          plots[[x]]$heights[8] <- plots[[x]]$heights[8]+width_grob
-        }
+        #Hier gaat iets mis. Ik weet niet waarom dit er oorspronkelijk stond..
+        # if(!x %in% model_mat[nrow(model_mat), ]){
+        #  plots[[x]]$heights[c(1)] <- unit(0, "cm")
+        #  plots[[x]]$heights[8] <- plots[[x]]$heights[8]+width_grob
+        # }
       }
-      #plots[-c(1:n_vars)] <- lapply(plots[-c(1:n_vars)], function(x) {
-
-
-      #x$heights <- fixed_heights
-      #    x
-      #})
 
       plots[[((n_vars - 1) * n_vars) + 1]] <- grob_legend
 
