@@ -348,7 +348,7 @@ prepare_graph.default <- function(edges = NULL,
                                   fix_coord = FALSE,
                                   ...
 ){
-  #browser()
+
   Args <- as.list(match.call())[-1]
   myfor <- formals(prepare_graph.default)
   for ( v in names(myfor)){
@@ -357,15 +357,19 @@ prepare_graph.default <- function(edges = NULL,
   }
 
   # Check if nodes exist in edges and layout --------------------------------
-  if(inherits(layout, c("matrix", "data.frame"))){
-    layout <- long_layout(layout)
-    if(any(duplicated(layout$name))){
-      stop("Some nodes are duplicated in the layout. The offending node names are: ", paste0(unique(layout$name[duplicated(layout$name)]), collapse = ", "))
+  if(!inherits(layout, "tidy_layout")){
+    if(inherits(layout, c("matrix", "data.frame"))){
+      layout <- long_layout(layout)
+      if(any(duplicated(layout$name))){
+        stop("Some nodes are duplicated in the layout. The offending node names are: ", paste0(unique(layout$name[duplicated(layout$name)]), collapse = ", "))
+      }
+    } else {
+      stop("Argument 'layout' must be a matrix or data.frame.")
     }
-    Args$layout <- layout
-  } else {
-    stop("Argument 'layout' must be a matrix or data.frame.")
   }
+
+  Args$layout <- layout
+
   if(!is.null(edges)){
     df_edges <- edges
   } else {
@@ -427,7 +431,11 @@ prepare_graph.default <- function(edges = NULL,
   if(!("name" %in% names(nodes) & "name" %in% names(layout))){
     stop("Arguments 'nodes' and 'layout' must both have a 'name' column.")
   }
-  df_nodes <- merge(nodes, layout, by = "name")
+  df_nodes <- nodes
+  if(!all(c("x", "y") %in% names(df_nodes))){
+    df_nodes <- merge(df_nodes, layout[, c("name", setdiff(names(layout), names(df_nodes))), drop = FALSE], by = "name")
+  }
+
   if(!"label" %in% names(df_nodes)){
     df_nodes$label <- df_nodes$name
   }
@@ -537,7 +545,6 @@ prepare_graph.lavaan <- function(model,
                                  layout = NULL,
                                  nodes = NULL,
                                  ...){
-  #browser()
 
   dots <- match.call(expand.dots = FALSE)[["..."]]
 
@@ -1644,7 +1651,7 @@ match.call.defaults <- function(...) {
     if(!"size" %in% names(df)){
       df$size <- text_size
     }
-    #browser()
+
     Args <- c("fill", "size", "family", "fontface", "hjust", "vjust", "lineheight", "colour","color",  "alpha", "geom_text")
     Args <- as.list(df[which(names(df) %in% Args)])
     Args <- c(list(
